Welcome to ordotools
====================

What?
    A Traditional Catholic Ordo and Calendar, written in Python.

Where?
    Visit out test website at https://ordo.media.

Install
-------

Be aware that this package is still in alpha, and there are known bugs.

``pip install ordotools``

Contributing
------------

See the `Wiki <https://github.com/corei8/ordotools/wiki>`_ for Project scope,
documentation, etc.


Support
-------

Give a ⭐️ if this project helped you!
